[][src]Enum mief::elements::ball::BallStatus

pub enum BallStatus {
    LeftOnLeftSide,
    LeftOnRightSide,
    WithinGame,
}

The current status of the ball.

Variants

LeftOnLeftSide

The ball left the field on the left side.

LeftOnRightSide

The ball left the field on the right side.

WithinGame

The ball is still within the field.